@@ -1,7 +1,7 @@
 package Sort::Sub;
 
-our $DATE = '2016-04-06'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-12-16'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -45,7 +45,7 @@ Sort::Sub - Collection of sort subroutines
 
 =head1 VERSION
 
-This document describes version 0.06 of Sort::Sub (from Perl distribution Sort-Sub), released on 2016-04-06.
+This document describes version 0.07 of Sort::Sub (from Perl distribution Sort-Sub), released on 2016-12-16.
 
 =head1 SYNOPSIS
 
@@ -75,7 +75,7 @@ Request a case-insensitive sort:
 
 Request a case-insensitive, reverse sort:
 
- use Sort::Sub qw($naturally<ir>;
+ use Sort::Sub qw($naturally<ir>);
 
  my @sorted = sort $naturally ('track2.mp3', 'Track1.mp3', 'Track10.mp3');
  => ('Track10.mp3', 'track2.mp3', 'Track1.mp3')
